@@ -5,9 +5,9 @@ import os
 import time
 
 
-def stackTodb(dataFrame, dbTableName):
+def stackTodb(dataFrame, dbTableName, skima):
     print(dataFrame)
-    db_connection_str = 'mysql+pymysql://root:12345@127.0.0.1:3307/stackline'
+    db_connection_str = 'mysql+pymysql://root:12345@127.0.0.1:3307/{skima}'.format(skima = skima)
     db_connection = create_engine(db_connection_str, encoding='utf-8')
     conn = db_connection.connect()
 
@@ -117,7 +117,7 @@ def unicodeProcess(dataframe):
     dataframe['title'] = dataframe['title'].str.replace(' ', ' ')
 
 
-def csvImporter_NEW(csv_folder_cleaned, keyword_pool):
+def csvImporter_NEW(csv_folder_cleaned, keyword_pool, skima):
     column_name = ["retailer_id", "retailer_name", "retailer_sku", "upc", "model_number", "title", "brand", "category", "subcategory", "week_id", "week_ending", "units_sold", "retail_sales", "retail_price", "conversion_rate", "total_traffic", "organic_traffic"]
 
     fileList = os.listdir(csv_folder_cleaned)
@@ -136,34 +136,35 @@ def csvImporter_NEW(csv_folder_cleaned, keyword_pool):
             db_table_name = 'tb_stackline_laptops'
             # commonPreprocess(dataframe)
             print("-----No Pool Check-----")
-            stackTodb(dataframe, db_table_name)
+            stackTodb(dataframe, db_table_name, skima)
 
         if "Earbud" in fileList[i]:
             db_table_name = 'tb_stackline_earbuds'
             # commonPreprocess(dataframe)
             print("-----No Pool Check-----")
-            stackTodb(dataframe, db_table_name)
+            stackTodb(dataframe, db_table_name, skima)
 
         ##### pool
         if "Watches" in fileList[i]:
             db_table_name = 'tb_stackline_watches'
             print("-----Pool Check-----")
-            stackTodb(addPoolColumn(dataframe, keyword_pool), db_table_name)
+            stackTodb(addPoolColumn(dataframe, keyword_pool), db_table_name, skima)
 
         if "Tablets" in fileList[i]:
             db_table_name = 'tb_stackline_tablets'
             print("-----Pool Check-----")
-            stackTodb(addPoolColumn(dataframe, keyword_pool), db_table_name)
+            stackTodb(addPoolColumn(dataframe, keyword_pool), db_table_name, skima)
 
         if "Phones" in fileList[i]:
             db_table_name = 'tb_stackline_smartphones'
             print("-----Pool Check-----")
-            stackTodb(addPoolColumn(dataframe, keyword_pool), db_table_name)
+            stackTodb(addPoolColumn(dataframe, keyword_pool), db_table_name, skima)
 
 
 def keywordCheck(csv_folder_cleaned, pool_check_folder, keyword_pool):
     column_name = ["retailer_id", "retailer_name", "retailer_sku", "upc", "model_number", "title", "brand", "category", "subcategory", "week_id", "week_ending", "units_sold", "retail_sales", "retail_price", "conversion_rate", "total_traffic", "organic_traffic"]
 
+
     pool = keywordPool(keyword_pool)
     title_mapping = titleSummaryMaker(keyword_pool)
 
